==> xdtp-1.1.4.tgz: xdtp-1.1.4/src/xml/xmlloader.cpp <==
/*
 * $Id: xmlloader.cpp,v 1.1 2005/10/19 14:05:44 ozawa Exp $
 *
 * Copyright 2005- ONGS Inc. All rights reserved.
 * 
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 1.1 $
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 * 
 */

#include "xdtp.h"
#include "xmlloader.h"

using namespace XDTP;

/**
 * 󥹥ȥ饯
 */
XMLLoader::XMLLoader()
{
}

/**
 * ǥȥ饯
 */
XMLLoader::~XMLLoader()
{
}

/**
 * XMLե뤫ɤ߹ߤޤ
 * 
 * @param aPath XMLե
 * @return XMLɥȡפˤʤäʳxmlFreeDocɬפޤ
 */
xmlDocPtr XMLLoader::load(const Glib::ustring& aPath)
{
    return xmlParseFile(aPath.c_str());
}

/**
 * XML꤫ɤ߹ߤޤ
 * 
 * @param aBuffer XMLʸ
 * @return XMLɥȡפˤʤäʳxmlFreeDocɬפޤ
 */
xmlDocPtr XMLLoader::loadMem(const Glib::ustring& aBuffer)
{
    return xmlParseMemory(aBuffer.c_str(), aBuffer.bytes());
}

==> xdtp-1.2.0.tgz: xdtp-1.2.0/src/xml/xmlloader.cpp <==
/*
 * $Id: xmlloader.cpp,v 1.2 2006/06/16 13:31:39 ozawa Exp $
 *
 * Copyright 2005- ONGS Inc. All rights reserved.
 * 
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 1.2 $
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 * 
 */

#include "xdtp.h"
#include "xmlloader.h"

using namespace XDTP;

/**
 * 󥹥ȥ饯
 */
XMLLoader::XMLLoader()
{
}

/**
 * ǥȥ饯
 */
XMLLoader::~XMLLoader()
{
}

/**
 * XMLե뤫ɤ߹ߤޤ
 * 
 * @param aPath XMLե
 * @return XMLɥȡפˤʤäʳxmlFreeDocɬפޤ
 */
xmlDocPtr XMLLoader::load(const Glib::ustring& aPath)
{
    return xmlParseFile(aPath.c_str());
}

/**
 * XML꤫ɤ߹ߤޤ
 * 
 * @param aBuffer ХåեXMLʸ
 * @param aBytes ХåեĹ
 * @return XMLɥȡפˤʤäʳxmlFreeDocɬפޤ
 */
xmlDocPtr XMLLoader::loadMem(const char* aBuffer, int aBytes)
{
    return xmlParseMemory(aBuffer, aBytes);
}

/**
 * XML꤫ɤ߹ߤޤ
 * 
 * @param aBuffer ХåեXMLʸ
 * @return XMLɥȡפˤʤäʳxmlFreeDocɬפޤ
 */
xmlDocPtr XMLLoader::loadMem(const Glib::ustring& aBuffer)
{
    return xmlParseMemory(aBuffer.c_str(), aBuffer.bytes());
}
